@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import math
 from datetime import datetime
 from collections import namedtuple
 
@@ -161,7 +162,11 @@ class IncompleteMultidimensionalProfile(CFDataset):
         first_row = df.iloc[0]
         first_loc = Point(first_row.x, first_row.y)
         if geometries:
-            coords = list(unique_justseen(zip(df.x, df.y)))
+            null_coordinates = df.x.isnull() | df.y.isnull()
+            coords = list(unique_justseen(zip(
+                df.x[~null_coordinates].tolist(),
+                df.y[~null_coordinates].tolist()
+            )))
             if len(coords) > 1:
                 geometry = LineString(coords)  # noqa
             elif len(coords) == 1:
