@@ -9,7 +9,9 @@ class ContiguousRaggedTrajectory(CFDataset):
         global_attributes = global_attributes or {}
         raise NotImplementedError
 
-    def calculated_metadata(self, geometries=True):        
+    def calculated_metadata(self, df=None, geometries=True, clean_cols=True, clean_rows=True):
+        # if df is None:
+        #     df = self.to_dataframe(clean_cols=clean_cols, clean_rows=clean_rows)
         raise NotImplementedError
 
     def to_dataframe(self):
