@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import math
 import tempfile
 
 from datetime import datetime
@@ -169,7 +170,11 @@ class IncompleteMultidimensionalTrajectory(CFDataset):
 
             geometry = None
             if geometries:
-                coords = list(unique_justseen(zip(tgroup.x, tgroup.y)))
+                null_coordinates = tgroup.x.isnull() | tgroup.y.isnull()
+                coords = list(unique_justseen(zip(
+                    tgroup.x[~null_coordinates].tolist(),
+                    tgroup.y[~null_coordinates].tolist()
+                )))
                 if len(coords) > 1:
                     geometry = LineString(coords)
                 elif coords == 1:
