@@ -76,7 +76,7 @@ class TestTimeSeries(unittest.TestCase):
         times = [0, 1000, 2000, 3000, 4000, 5000]
         verticals = 0
         values = [20, 21, 22, 23, 24, 25]
-        attrs = dict(standard_name='sea_water_temperature')
+        attrs = dict(standard_name='sea_water_temperature', units='degree_Celsius')
 
         # From dataframe
         df = pd.DataFrame({
@@ -115,6 +115,7 @@ class TestTimeSeries(unittest.TestCase):
         assert nc.variables.get('time').size == len(times)
         assert nc.variables.get('time')[:].dtype == np.int32
         assert nc.variables.get('temperature').size == len(times)
+        assert nc.variables.get('temperature').long_name == 'Sea Water Temperature (degree_Celsius)'
         assert (nc.variables.get('temperature')[:] == np.asarray(values)).all()
 
     def test_timeseries_extra_values(self):
@@ -155,6 +156,7 @@ class TestTimeSeries(unittest.TestCase):
         assert nc.variables.get('time')[:].dtype == np.int32
         assert nc.variables.get('temperature').size == len(times)
         assert (nc.variables.get('temperature')[:] == np.asarray(values[0:6])).all()
+        assert nc.variables.get('temperature').long_name == 'Sea Water Temperature'
 
     def test_timeseries_profile(self):
         filename = 'test_timeseries_profile.nc'
@@ -170,7 +172,7 @@ class TestTimeSeries(unittest.TestCase):
                         verticals=verticals)
 
         values = np.repeat([20, 21, 22, 23, 24, 25], len(verticals))
-        attrs = dict(standard_name='sea_water_temperature')
+        attrs = dict(standard_name='sea_water_temperature', vertical_datum='NAVD88')
         ts.add_variable('temperature', values=values, attributes=attrs)
 
         nc = netCDF4.Dataset(os.path.join(self.output_directory, filename))
@@ -182,6 +184,7 @@ class TestTimeSeries(unittest.TestCase):
         self.assertEqual(nc.geospatial_lon_units, 'degrees_east')
         self.assertEqual(nc.geospatial_vertical_units, 'meters')
         self.assertEqual(nc.geospatial_vertical_positive, 'down')
+        self.assertEqual(nc.geospatial_bounds_vertical_crs, 'NAVD88')
         self.assertEqual(nc.featureType, 'timeSeriesProfile')
         self.assertEqual(nc.geospatial_vertical_resolution, '1 1')
         self.assertEqual(nc.geospatial_vertical_min, 0)
@@ -660,6 +663,7 @@ class TestTimeSeries(unittest.TestCase):
 
         gats = copy(self.global_attributes)
         gats['naming_authority'] = 'pyaxiom'
+        gats['geospatial_bounds_vertical_crs'] = 'NAVD88'
 
         ts = TimeSeries(output_directory=self.output_directory,
                         latitude=self.latitude,
@@ -672,14 +676,14 @@ class TestTimeSeries(unittest.TestCase):
 
         values = [20, 21, 22, 23, 24, 25]
         attrs = dict(standard_name='sea_water_temperature')
-        ts.add_variable('temperature', values=values, attributes=attrs, create_instrument_variable=True)
+        ts.add_variable('temperature', values=values, attributes=attrs, create_instrument_variable=True, sensor_vertical_datum='bar')
 
         nc = netCDF4.Dataset(os.path.join(self.output_directory, filename))
         assert nc is not None
+        assert nc.geospatial_bounds_vertical_crs == 'NAVD88'  # First one set
 
         datavar = nc.variables.get('temperature')
         instrument_var_name = datavar.instrument
-
         instvar = nc.variables[instrument_var_name]
         assert instvar.short_name == 'sea_water_temperature'
         assert instvar.ioos_code == urnify(gats['naming_authority'], gats['id'], attrs)
